require "box2d"

scene = Core.class(Sprite)


function scene:wall(x, y, width, height)
	local wall = Shape.new()
	wall:beginPath()
	
	wall:moveTo(-width/2,-height/2)
    wall:lineTo(width/2, -height/2)
    wall:lineTo(width/2, height/2)
    wall:lineTo(-width/2, height/2)
    wall:closePath()
    wall:endPath()
    wall:setPosition(x,y)
	
	local wallBody = self.world:createBody{type = b2.STATIC_BODY}
	wallBody:setPosition(wall:getX(), wall:getY())
	wallBody:setAngle(wall:getRotation() * math.pi/180)
	local wallPoly = b2.PolygonShape.new()
	wallPoly:setAsBox(wall:getWidth()/2, wall:getHeight()/2)
	local wallFixture = wallBody:createFixture{shape = wallPoly, density = 1.0, friction = 0.1, restitution = 0,2}
	wall.body = wallBody
	wall.body.type = "wall"
	
	self:addChild(wall)
	
	return wall
	
end

-- for creating objects using image
-- as example - ball


function scene:addControls(x,y)
local texture = Texture.new("ptex.png")

local leftButtonRegion = TextureRegion.new(texture,0,0,100,100)
local rightButtonRegion = TextureRegion.new(texture,0,100,100,100)

local leftButton = Bitmap.new(leftButtonRegion)
local rightButton = Bitmap.new(rightButtonRegion)
leftButton.name = "leftButton"
rightButton.name = "rightButton"

leftButton:setPosition(x,y)
rightButton:setPosition(x+120, y)

self:addChild(leftButton)
self:addChild(rightButton)


rightButton:addEventListener(Event.MOUSE_DOWN, onMouseDown, rightButton)
rightButton:addEventListener(Event.MOUSE_UP, onMouseUp, rightButton)

leftButton:addEventListener(Event.MOUSE_DOWN, onMouseDown, leftButton)
leftButton:addEventListener(Event.MOUSE_UP, onMouseUp, leftButton)




end

function onMouseDown(self, event)

--local playerpos = getPosition(scene.Player.getX(), scene.Player.getY())

	if(self:hitTestPoint(event.x, event.y)) then

		if self.name == "leftButton" then

		end

		if self.name == "rightButton" then

		end
	end

end


function onMouseUp(self, event)

	if(self:hitTestPoint(event.x, event.y)) then

		if self.name == "leftButton" then
		print("Left Press UP")
		end

		if self.name == "rightButton" then
		print("Right Press UP")
		end
	end

end


--running the world
function scene:onEnterFrame() 
    -- edit the step values if required. These are good defaults!
    self.world:step(1/60, 8, 3)
    --iterate through all child sprites
    for i = 1, self:getNumChildren() do
	
        --get specific sprite
        local sprite = self:getChildAt(i)
        -- check if sprite HAS a body (ie, physical object reference we added)
        if sprite.body then
            --update position to match box2d world object's position
            --get physical body reference
            local body = sprite.body
            --get body coordinates
            local bodyX, bodyY = body:getPosition()
            --apply coordinates to sprite
            sprite:setPosition(bodyX, bodyY)
            --apply rotation to sprite
            sprite:setRotation(body:getAngle() * 180 / math.pi)
        end
    end
end


--on scene initialization
function scene:init()
    --create world instance
    world = b2.World.new(0, 10, true)
    self.world = world
     
    local screenW = application:getContentWidth()
    local screenH = application:getContentHeight()
    --create bounding walls outside the scene
    self:wall(0,screenH/2,10,screenH)
    self:wall(screenW/2,0,screenW,10)
    self:wall(screenW,screenH/2,10,screenH)
    self:wall(screenW/2,screenH,screenW,10)
     
    --create ball
    local Player = Player.new(100, 100)
	self:addChild(Player)
	
	self:addControls(50,850)
     
    --set up debug drawing
    local debugDraw = b2.DebugDraw.new()
    self.world:setDebugDraw(debugDraw)
    self:addChild(debugDraw)
     
    --run world
    self:addEventListener(Event.ENTER_FRAME, self.onEnterFrame, self)
    --remove event on exiting scene
    --self:addEventListener("exitBegin", self.onExitBegin, self)
	
end



--add created scene to stage or sceneManager
local mainScene = scene.new()
stage:addChild(mainScene)

